import uwsgi
from os import path

uwsgi.snmp_set_counter64(1, 0)  # Number of requests
uwsgi.snmp_set_counter64(2, 0)  # Number of bytes

def application(environ, start_response):
    size = path.getsize('logo_uWSGI.png')
    start_response('200 OK', [('Content-Type', 'image/png'), ('Content-Length', str(size))] )
    fd = open('logo_uWSGI.png','r')
    uwsgi.snmp_incr_counter64(1)
    uwsgi.snmp_incr_counter64(2, size)
    return environ['wsgi.file_wrapper'](fd, 4096)



# uwsgi --spooler-external t/spooler/spooldir --mule --mule --wsgi-file t/spooler/read.py --http :8080

from uwsgidecorators import spoolraw, muleloop

import uwsgi
import time
import collections
import random
import os

spooling_directory = uwsgi.opt['spooler-external']

@muleloop(1)
def reader():
    c = collections.Counter()

    for file in os.listdir(spooling_directory):
        try:
            task_dest = uwsgi.spooler_get_task(spooling_directory + "/" + file)["dest"]
            c[task_dest] += 1
        except Exception as e:
            print(e)

    print(c)
    time.sleep(5)

projects = ["uwsgi", "python", "ruby", "nginx", "memcache"]

@muleloop(2)
def producer():
    uwsgi.spool(ud_spool_func="consumer", dest=random.choice(projects))
    time.sleep(2)



import werkzeug
import uwsgi

def zero_app(e,s):
    s('200 OK', [ ('Content-Type', 'text/plain') ])
    return "0"

def not_found(e,s):
    s('404 Not Found', [ ('Content-Type', 'text/plain') ])
    return ""


def wsgi_app(e, s):
    s('200 OK', [ ('Content-Type', 'text/plain') ])
    yield "I am a WSGI app\n"


def internal_server_error(e, s):
    s('500 Internal Server Error', [ ('Content-Type', 'text/plain') ])
    return ""

uwsgi.applications = {'/wsgi':wsgi_app, '/test':werkzeug.test_app, '/zero':zero_app, '/notfound':not_found, '/ise':internal_server_error}



# run it with:
# export SPOOLER_DIR=t/python/spooler_priority/temporary_spooler; # or your spooler dir
# ./uwsgi t/python/spooler_decorators/spooler_decorator_test.ini

import unittest
import uwsgi
import spooler_handlers
from os import remove, path


class BitmapTest(unittest.TestCase):

    def setUp(self):
        try:
            remove(spooler_handlers.ghostpath)
        except OSError:  # file does not exist
            pass

        spooler_handlers.controlled_task.spool(arg='alive', ghost='world')
        spooler_handlers.controlled_task.spool(arg='barbis')
        spooler_handlers.controlled_raw_task.spool(arg='alive', ghost='world')
        spooler_handlers.controlled_raw_task.spool(arg='barbis')
        spooler_handlers.controlled_arguments_task.spool(
            {'key': 'value'}, 2, key1='value1')

        for i in range(5):
            uwsgi.signal_wait(20)
        print("Signal received!")

    def test_spooler(self):
        self.assertFalse(path.exists(spooler_handlers.ghostpath))

unittest.main()



# ./uwsgi --master --http :8080 --harakiri 1 --wsgi-file tests/harakiri.py --harakiri-graceful-timeout 1 --py-call-osafterfork --lazy-apps --enable-threads --threads 2 --harakiri-graceful-signal 31
import time
import uwsgi
import signal
import sys
import atexit

def sig_handler(n, fp):
    print("[Python App] attempting graceful shutdown triggered by harakiri (signal %d)" % n)
    exit(1)

def application(e, s):
    print("[Python App] sleeping")
    time.sleep(3)
    s('200 OK', [('Content-Type', 'text/html')])
    return [b"OK"]


def exit_handler():
    time.sleep(3)
    # Should not reach this line (graceful harakiri deadline expired)
    print("[Python App] exiting now")

atexit.register(exit_handler)
signal.signal(signal.SIGSYS, sig_handler)



import sys
import uwsgi

import envoxy

_apply = envoxy.log.style.apply

envoxy.log.system('\n\n')
envoxy.log.system(_apply('======================================', envoxy.log.style.BLUE_FG))
envoxy.log.system(_apply('=== ENVOXY Bootstrap System Loader ===', envoxy.log.style.BLUE_FG))
envoxy.log.system(_apply('======================================', envoxy.log.style.BLUE_FG))
envoxy.log.system('\n\n')
envoxy.log.system(_apply('>>> I am the bootstrap for uwsgi.SymbolsImporter', envoxy.log.style.BOLD))
envoxy.log.system('\n\n')

sys.meta_path.insert(0, uwsgi.SymbolsImporter())



import uwsgi

import random
import string

items = {}

def gen_rand_n(max_n):
    return random.randint(8, max_n)

def gen_rand_s(size):
    return ''.join( [ random.choice(string.letters) for i in range(size) ])

print 'filling cache...'
for i in range(0, 1000):
   kl = gen_rand_n(200)
   key = gen_rand_s(kl)
   vl = gen_rand_n(10000)
   val = gen_rand_s(vl)
   items[key] = val
   uwsgi.cache_set(key, val)

print 'checking cache...'
count = 0
for key in items.keys():
    val = uwsgi.cache_get(key)
    count += 1
    if val != items[key]:
         print len(val), val
         print len(items[key]), items[key]
         raise Exception('CACHE TEST FAILED AFTER %d ITERATIONS !!!' % count)

print "TEST PASSED"



#!/usr/bin/env python

import os
from setuptools import setup, find_packages
from setuptools.command.install import install

from subprocess import check_call

data_dir = os.path.dirname(os.path.realpath(__file__))


def find_file(path):
    return os.path.join(data_dir, path)


class InstallCommand(install):

    description = "install envoxyd"

    def run(self):
        check_call(["python3.11", "uwsgiconfig.py", "--build", "flask"], cwd="src/envoxyd")
        install.run(self)


setup(
    name="envoxyd",
    version="0.2.1",
    description="Envoxyd",
    author="Matheus Santos",
    author_email="vorj.dux@gmail.com",
    url="https://github.com/muzzley/envoxy",
    packages=find_packages(exclude=["uwsgi", "templates", "tests"]),
    install_requires=["envoxy>=0.3.0", "flask-cors==4.0.2", "isort>=4.2.5,<5"],
    package_dir={
        "envoxyd": "envoxyd/",
    },
    data_files=[
        ("bin", ["src/envoxyd/envoxyd"]),
        ("bin", ["envoxyd/tools/envoxy-cli"]),
        ("envoxyd", ["LICENSE.txt"]),
        ("envoxyd/etc/templates", ["envoxyd/templates/__init__.py"]),
        ("envoxyd/etc/templates", ["envoxyd/templates/run.py"]),
        ("envoxyd/etc/templates/confs", ["envoxyd/templates/confs/envoxy.json"]),
        ("envoxyd/etc/templates/views", ["envoxyd/templates/view.py"]),
    ],
    cmdclass={"install": InstallCommand},
    python_requires=">=3.11",
    include_package_data=True,
)



jvm_path = 'plugins/jvm'

up = {}
try:
    execfile('%s/uwsgiplugin.py' % jvm_path, up)
except:
    f = open('%s/uwsgiplugin.py' % jvm_path)
    exec(f.read(), up)
    f.close()

NAME='jwsgi'
CFLAGS = up['CFLAGS']
CFLAGS.append('-I%s' % jvm_path)
LDFLAGS = []
LIBS = []
GCC_LIST = ['jwsgi_plugin']



import envoxy

# watchdog
try:
    keep_alive = envoxy.Config.get('boot')[0].get('keep_alive', 0)
    envoxy.Watchdog(int(keep_alive)).start()
except (KeyError, TypeError, ValueError, IndexError) as e:
    envoxy.log.system('[{}] watchdog not enabled, keep_alive missing! {}'.format(
        envoxy.log.style.apply('---', envoxy.log.style.YELLOW_FG), e
    ))



import json
import os

import envoxy
import uwsgi

if 'conf' in uwsgi.opt:

    _conf_path = uwsgi.opt['conf'].decode('utf-8')

    envoxy.log.system('[{}] Configuration file param found: {}\n'.format(
        envoxy.log.style.apply('OK', envoxy.log.style.GREEN_FG),
        _conf_path
    ))

    if os.path.exists(_conf_path) and os.path.isfile(_conf_path):

        envoxy.log.system('[{}] Configuration file exists! Trying to parse the file...\n'.format(
            envoxy.log.style.apply('---', envoxy.log.style.BLUE_FG)
        ))

        _module_name = os.path.basename(_conf_path).replace('.json', '')

        # try:
        _conf_file = open(_conf_path, encoding='utf-8')
        _conf_content = json.loads(_conf_file.read())
        envoxy.log.system('[{}] The configuration file was parsed successfully!\n\n'.format(
            envoxy.log.style.apply('OK', envoxy.log.style.GREEN_FG)
        ))

        uwsgi.opt['conf_content'] = _conf_content

        _log_conf = _conf_content.get('log') or _conf_content.get('$log')

        if _log_conf and _log_conf.get('level'):
            uwsgi.opt['log-level'] = bytes([int(_log_conf['level'])])

        if _log_conf and _log_conf.get('format'):
            uwsgi.opt['log-format'] = _log_conf['format']

    else:

        envoxy.log.emergency(
            'Configuration file not found in this path! Please check if the file exists or the permissions are enough.\n\n')
        exit(-10)

elif 'mode' not in uwsgi.opt:
    envoxy.log.emergency(
        'Configuration file not found! Please use ./envoxy [params] --set conf=<file> or ./envoxy [params] --set mode=test\n\n')
    exit(-10)
